@@ -142,7 +142,7 @@
     }
     if (ctrl$mtry < Inf) {
         mtry <- min(length(svars), ctrl$mtry)
-        svars <- .resample(svars, mtry, prob = partyvars[svars])
+        svars <- .resample(svars, size = mtry, prob = partyvars[svars])
     } 
 
     thismodel <- trafo(subset = subset, weights = weights, info = info, 
@@ -688,11 +688,15 @@ extree_data <- function(formula, data, subset, na.action = na.pass, weights, off
     } else { ### ytype = "matrix"
         Ytmp <- model.matrix(~ 0 + ., Formula::model.part(formula, yxmf, lhs = TRUE))
         ### <FIXME> are there cases where Ytmp already has missings? </FIXME>
-        if (length(ret$yxmissings) == 0) {
+        if (is.finite(nmax["yx"])) {
             Ymat <- Ytmp
         } else {
-            Ymat <- matrix(0, nrow = NROW(yxmf), ncol = NCOL(Ytmp))
-            Ymat[-ret$yxmissings,] <- Ytmp
+            if (length(ret$yxmissings) == 0) {
+                Ymat <- Ytmp
+            } else {
+                Ymat <- matrix(0, nrow = NROW(yxmf), ncol = NCOL(Ytmp))
+                Ymat[-ret$yxmissings,] <- Ytmp
+            }
         }
         yx <- list("y" = Ymat)
     }
@@ -700,11 +704,15 @@ extree_data <- function(formula, data, subset, na.action = na.pass, weights, off
       ni <- paste("x", if(i == 1L) "" else i, sep = "")
       ti <- if(!ymult & npart == 2L) mt$yx else mt[[ni]]
       Xtmp <- model.matrix(ti, yxmf)
-      if (length(ret$yxmissings) == 0) {
+      if (is.finite(nmax["yx"])) {
           Xmat <- Xtmp
       } else {
-          Xmat <- matrix(0, nrow = NROW(yxmf), ncol = NCOL(Xtmp))
-          Xmat[-ret$yxmissings,] <- Xtmp
+          if (length(ret$yxmissings) == 0) {
+              Xmat <- Xtmp
+          } else {
+              Xmat <- matrix(0, nrow = NROW(yxmf), ncol = NCOL(Xtmp))
+              Xmat[-ret$yxmissings,] <- Xtmp
+          }
       }
       yx[[ni]] <- Xmat
       if(ncol(yx[[ni]]) < 1L) {
